@@ -5,12 +5,12 @@ use warnings;
 
 package MongoDBI;
 {
-    $MongoDBI::VERSION = '0.0.1';
+    $MongoDBI::VERSION = '0.0.1_01';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.1';    # VERSION
+our $VERSION = '0.0.1_01';    # VERSION
 
 use Moose ('extends');
 
@@ -28,7 +28,7 @@ MongoDBI - A proper ODM (Object-Document-Mapper) for MongoDB
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.1_01
 
 =head1 SYNOPSIS
 
@@ -63,9 +63,9 @@ version 0.0.1
     my $cds  = $cddb->class('Album'); # grabs CDDB::Album
     
     # find cds released during or after the year 2000
-    my $year_2000 = DateTime->now->set(year => 2000, month => 1, day => 1);
+    my $year_2000 = DateTime->set(year => 2000, month => 1, day => 1);
 
-    my $search = $cds->search->where('released$gt' => $year_2000)->query;
+    my $search $cds->search->where('released$gt' => $year_2000)->query;
     
     while (my $cd = $search->next) {
         
@@ -89,9 +89,9 @@ automated indexing, moose-integration (inheritance support, etc), lean
 document updates via dirty field tracking, and ability for each class to be
 configured to use a different database and connection, etc.
 
-Note! This library is still in its infancy and subject to change in code and
-in the overall design. The POD (documentation) may also be lacking in certain
-areas, for additional insight you may examine the accompanying tests.
+Note! This library is still in its infancy and subject to change. The POD
+(documentation) may also be lacking in certain areas, for additional insight
+you may examine the accompanying tests.
 
 This class, MongoDBI, sub-classes L<MongoDBI::Application>, please review that
 module for more usage information.
