@@ -5,12 +5,12 @@ use warnings;
 
 package MongoDBI::Document;
 {
-    $MongoDBI::Document::VERSION = '0.0.1';
+    $MongoDBI::Document::VERSION = '0.0.1_01';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.1';    # VERSION
+our $VERSION = '0.0.1_01';    # VERSION
 
 use Moose ('extends');
 
@@ -28,7 +28,7 @@ MongoDBI::Document - Defines and Represents a MongoDB Collection and Document
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.1_01
 
 =head1 SYNOPSIS
 
@@ -221,8 +221,8 @@ accessible as follows:
     }
     
     # or, ... directly access the history
-    $cd->_dirty->{title}->[2]->{new_value}; # 3rd title change
-    $cd->_dirty->{title}->[2]->{old_value}; # value before 3rd title change
+    $cd->_dirty->{title}->[2]->{new_value}; # 2nd title change
+    $cd->_dirty->{title}->[2]->{old_value}; # value before 2nd title change
 
 =head2 CLASS INHERITANCE
 
@@ -294,7 +294,7 @@ can be used:
     ... etc
     
     my $search = CDDB::Album->search;
-       $search = $search->where('released$lt' => DateTime->now->set(...));
+       $search = $search->where('released$lt' => DateTime->set(...));
        $search = $search->asc_sort('title')->limit(25);
        
     my $mongodb_cursor = $search->query;
@@ -342,7 +342,7 @@ parent document. The relational (referenced) document relationship describes
 a document(s) referenced by separate document in separate collection.
 
 MongoDBI::Document classes declared to be related to other document classes are
-wrapped by object-based proxies for the actual document class which provides
+wrapped by object-based proxies for the actual document class which provide
 functionality for accessing, replacing, appending and persisting.
 
 Consider the following example which declares both an embedded and relational
