@@ -1,16 +1,16 @@
-# Base Class for a MongoDBI Document Class
+# ABSTRACT: Base Class for a MongoDBI Document Class
 
 use strict;
 use warnings;
 
 package MongoDBI::Document::Base;
 {
-    $MongoDBI::Document::Base::VERSION = '0.0.1';
+    $MongoDBI::Document::Base::VERSION = '0.0.1_01';
 }
 
 use 5.001000;
 
-our $VERSION = '0.0.1';    # VERSION
+our $VERSION = '0.0.1_01';    # VERSION
 
 use Moose ('with');
 use Moose::Exporter;
@@ -110,3 +110,28 @@ sub unimport {
 }
 
 1;
+__END__
+
+=pod
+
+=head1 NAME
+
+MongoDBI::Document::Base - Base Class for a MongoDBI Document Class
+
+=head1 VERSION
+
+version 0.0.1_01
+
+=head1 AUTHOR
+
+Al Newkirk <awncorp@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2011 by awncorp.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
